@@ -62,6 +62,9 @@ public:
             stylePathList += stylesPath;
         }
 
+        // Path for backwards compatibility
+        stylePathList << QLatin1String("qrc:/QtQuick/VirtualKeyboard/content/styles/");
+
         for (const QString &stylePath : std::as_const(stylePathList)) {
             QString filePath = buildStyleFilePath(stylePath, name);
             bool pathExist = false;
@@ -96,6 +99,7 @@ public:
     \qmltype VirtualKeyboardSettings
     \inqmlmodule QtQuick.VirtualKeyboard.Settings
     \ingroup qtvirtualkeyboard-settings-qml
+    \ingroup qmlclass
     \since QtQuick.VirtualKeyboard 1.2
     \brief Provides settings for virtual keyboard.
 
@@ -148,6 +152,8 @@ QQuickVirtualKeyboardSettings::QQuickVirtualKeyboardSettings(QQmlEngine *engine,
     connect(settings, SIGNAL(handwritingModeDisabledChanged()), SIGNAL(handwritingModeDisabledChanged()));
     connect(settings, SIGNAL(defaultInputMethodDisabledChanged()), SIGNAL(defaultInputMethodDisabledChanged()));
     connect(settings, SIGNAL(defaultDictionaryDisabledChanged()), SIGNAL(defaultDictionaryDisabledChanged()));
+    connect(settings, SIGNAL(visibleFunctionKeysChanged()), SIGNAL(visibleFunctionKeysChanged()));
+    connect(settings, &Settings::keySoundVolumeChanged, this, &QQuickVirtualKeyboardSettings::keySoundVolumeChanged);
 }
 
 /*!
@@ -348,6 +354,46 @@ void QQuickVirtualKeyboardSettings::setDefaultDictionaryDisabled(bool defaultDic
     return Settings::instance()->setDefaultDictionaryDisabled(defaultDictionaryDisabled);
 }
 
+QtVirtualKeyboard::KeyboardFunctionKeys QQuickVirtualKeyboardSettings::visibleFunctionKeys() const
+{
+    return Settings::instance()->visibleFunctionKeys();
+}
+
+void QQuickVirtualKeyboardSettings::setVisibleFunctionKeys(QtVirtualKeyboard::KeyboardFunctionKeys newVisibleFunctionKeys)
+{
+    Settings::instance()->setVisibleFunctionKeys(newVisibleFunctionKeys);
+}
+
+bool QQuickVirtualKeyboardSettings::closeOnReturn() const
+{
+    return Settings::instance()->closeOnReturn();
+}
+
+void QQuickVirtualKeyboardSettings::setCloseOnReturn(bool closeOnReturn)
+{
+    Settings::instance()->setCloseOnReturn(closeOnReturn);
+}
+
+qreal QQuickVirtualKeyboardSettings::keySoundVolume() const
+{
+    return Settings::instance()->keySoundVolume();
+}
+
+void QQuickVirtualKeyboardSettings::setKeySoundVolume(qreal volume)
+{
+    Settings::instance()->setKeySoundVolume(volume);
+}
+
+/*!
+    \internal
+*/
+qreal QQuickVirtualKeyboardSettings::convertVolume(qreal volume) const
+{
+    // Equivalent to QAudio::convertVolume(volume / 100, QtAudio::LogarithmicVolumeScale, QtAudio::LinearVolumeScale)
+    constexpr qreal LOG100 = 4.60517018599;
+    return 1 - std::exp(-(volume / 100) * LOG100);
+}
+
 void QQuickVirtualKeyboardSettings::resetStyle()
 {
     Q_D(QQuickVirtualKeyboardSettings);
@@ -357,7 +403,7 @@ void QQuickVirtualKeyboardSettings::resetStyle()
     QString customStyleName = QString::fromLatin1(qgetenv("QT_VIRTUALKEYBOARD_STYLE"));
     if (!customStyleName.isEmpty()) {
         bool found = false;
-        QRegularExpression styleNameValidator(QLatin1String("\\A(?:\\w+)\\z"));
+        static const QRegularExpression styleNameValidator(QLatin1String("\\A(?:\\w+)\\z"));
         QRegularExpressionMatch match = styleNameValidator.match(customStyleName);
         if (match.hasMatch()) {
             QString customStyle = d->stylePath(customStyleName);
@@ -527,6 +573,43 @@ void QQuickVirtualKeyboardSettings::resetStyle()
     use a custom dictionary only instead of the standard dictionary.
 */
 
+/*!
+    \qmlproperty enumeration VirtualKeyboardSettings::visibleFunctionKeys
+    \since QtQuick.VirtualKeyboard.Settings 6.6
+
+    This setting adjusts the visibility of specific function keys in the keyboard layout, allowing
+    them to be either displayed or hidden. When a function key is not visible, its functionality
+    remains accessible through the gear menu.
+
+    The value can be combination of the following flags:
+
+    \list
+        \li \c QtVirtualKeyboard.KeyboardFunctionKeys.None All function keys are hidden
+        \li \c QtVirtualKeyboard.KeyboardFunctionKeys.Hide Hide function key is visible
+        \li \c QtVirtualKeyboard.KeyboardFunctionKeys.Language Language function key is visible
+        \li \c QtVirtualKeyboard.KeyboardFunctionKeys.All All function keys are visible
+    \endlist
+
+    The default is \c QtVirtualKeyboard.KeyboardFunctionKeys.All.
+*/
+
+/*!
+    \qmlproperty bool VirtualKeyboardSettings::closeOnReturn
+    \since QtQuick.VirtualKeyboard.Settings 6.8
+
+    This property enables hiding of virtual keyboard.
+
+    When this property is set to \c true, the virtual keyboard is hidden when \l Qt::Key_Enter
+    or \l Qt::Key_Return key released. The default is \c false.
+*/
+
+/*!
+    \qmlproperty real VirtualKeyboardSettings::keySoundVolume
+    \since QtQuick.VirtualKeyboard.Settings 6.9
+
+    This property holds the keysound's volume level. The level is in the range [0,1]
+*/
+
 /*!
     \since QtQuick.VirtualKeyboard.Settings 2.2
     \qmlproperty int VirtualKeyboardSettings::wordCandidateList.autoHideDelay
